@@ -73,6 +73,26 @@ test_that('no error precision_6', {expect_false(inherits(precision_6.test, "try-
 test_that('no error precision_5', {expect_false(inherits(precision_7.test, "try-error")) })
 test_that('no error precision_6', {expect_false(inherits(precision_8.test, "try-error")) })
 
+# 3b. Positive Predictive Value
+ppv_1.test <- ppv(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 1)
+ppv_2.test <- ppv(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 1)
+ppv_3.test <- ppv(data = multiclass, obs = labels, pred = predictions, tidy = FALSE)
+ppv_4.test <- ppv(data = multiclass, obs = labels, pred = predictions, tidy = TRUE)
+ppv_5.test <- ppv(data = multiclass, obs = labels, pred = predictions, tidy = FALSE, atom = TRUE)
+ppv_6.test <- ppv(data = multiclass, obs = labels, pred = predictions, tidy = TRUE, atom = TRUE)
+ppv_7.test <- ppv(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 2)
+ppv_8.test <- ppv(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 2)
+
+# TEST
+test_that('no error ppv_1', {expect_false(inherits(ppv_1.test, "try-error")) })
+test_that('no error ppv_2', {expect_false(inherits(ppv_2.test, "try-error")) })
+test_that('no error ppv_3', {expect_false(inherits(ppv_3.test, "try-error")) })
+test_that('no error ppv_4', {expect_false(inherits(ppv_4.test, "try-error")) })
+test_that('no error ppv_5', {expect_false(inherits(ppv_5.test, "try-error")) })
+test_that('no error ppv_6', {expect_false(inherits(ppv_6.test, "try-error")) })
+test_that('no error ppv_5', {expect_false(inherits(ppv_7.test, "try-error")) })
+test_that('no error ppv_6', {expect_false(inherits(ppv_8.test, "try-error")) })
+
 # 4. Recall
 recall_1.test <- recall(data = binary, obs = labels, pred = predictions, tidy = FALSE, atom = FALSE, pos_level = 1)
 recall_2.test <- recall(data = binary, obs = labels, pred = predictions, tidy = TRUE, atom = FALSE, pos_level = 1)
@@ -93,6 +113,66 @@ test_that('no error recall_6', {expect_false(inherits(recall_6.test, "try-error"
 test_that('no error recall_7', {expect_false(inherits(recall_7.test, "try-error")) })
 test_that('no error recall_8', {expect_false(inherits(recall_8.test, "try-error")) })
 
+  # 4.b Sensitivity
+sensitivity_1.test <- sensitivity(data = binary, obs = labels, pred = predictions, tidy = FALSE, atom = FALSE, pos_level = 1)
+sensitivity_2.test <- sensitivity(data = binary, obs = labels, pred = predictions, tidy = TRUE, atom = FALSE, pos_level = 1)
+sensitivity_3.test <- sensitivity(data = multiclass, obs = labels, pred = predictions, tidy = FALSE, atom = FALSE)
+sensitivity_4.test <- sensitivity(data = multiclass, obs = labels, pred = predictions, tidy = TRUE, atom = FALSE)
+sensitivity_5.test <- sensitivity(data = multiclass, obs = labels, pred = predictions, tidy = FALSE, atom = TRUE)
+sensitivity_6.test <- sensitivity(data = multiclass, obs = labels, pred = predictions, tidy = TRUE, atom = TRUE)
+sensitivity_7.test <- sensitivity(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 2)
+sensitivity_8.test <- sensitivity(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 2)
+
+# TEST
+test_that('no error sensitivity_1', {expect_false(inherits(sensitivity_1.test, "try-error")) })
+test_that('no error sensitivity_2', {expect_false(inherits(sensitivity_2.test, "try-error")) })
+test_that('no error sensitivity_3', {expect_false(inherits(sensitivity_3.test, "try-error")) })
+test_that('no error sensitivity_4', {expect_false(inherits(sensitivity_4.test, "try-error")) })
+test_that('no error sensitivity_5', {expect_false(inherits(sensitivity_5.test, "try-error")) })
+test_that('no error sensitivity_6', {expect_false(inherits(sensitivity_6.test, "try-error")) })
+test_that('no error sensitivity_7', {expect_false(inherits(sensitivity_7.test, "try-error")) })
+test_that('no error sensitivity_8', {expect_false(inherits(sensitivity_8.test, "try-error")) })
+
+  # 4.c True Positive Rate
+TPR_1.test <- TPR(data = binary, obs = labels, pred = predictions, tidy = FALSE, atom = FALSE, pos_level = 1)
+TPR_2.test <- TPR(data = binary, obs = labels, pred = predictions, tidy = TRUE, atom = FALSE, pos_level = 1)
+TPR_3.test <- TPR(data = multiclass, obs = labels, pred = predictions, tidy = FALSE, atom = FALSE)
+TPR_4.test <- TPR(data = multiclass, obs = labels, pred = predictions, tidy = TRUE, atom = FALSE)
+TPR_5.test <- TPR(data = multiclass, obs = labels, pred = predictions, tidy = FALSE, atom = TRUE)
+TPR_6.test <- TPR(data = multiclass, obs = labels, pred = predictions, tidy = TRUE, atom = TRUE)
+TPR_7.test <- TPR(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 2)
+TPR_8.test <- TPR(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 2)
+
+# TEST
+test_that('no error TPR_1', {expect_false(inherits(TPR_1.test, "try-error")) })
+test_that('no error TPR_2', {expect_false(inherits(TPR_2.test, "try-error")) })
+test_that('no error TPR_3', {expect_false(inherits(TPR_3.test, "try-error")) })
+test_that('no error TPR_4', {expect_false(inherits(TPR_4.test, "try-error")) })
+test_that('no error TPR_5', {expect_false(inherits(TPR_5.test, "try-error")) })
+test_that('no error TPR_6', {expect_false(inherits(TPR_6.test, "try-error")) })
+test_that('no error TPR_7', {expect_false(inherits(TPR_7.test, "try-error")) })
+test_that('no error TPR_8', {expect_false(inherits(TPR_8.test, "try-error")) })
+
+  # 4.d Hit Rate
+hitrate_1.test <- hitrate(data = binary, obs = labels, pred = predictions, tidy = FALSE, atom = FALSE, pos_level = 1)
+hitrate_2.test <- hitrate(data = binary, obs = labels, pred = predictions, tidy = TRUE, atom = FALSE, pos_level = 1)
+hitrate_3.test <- hitrate(data = multiclass, obs = labels, pred = predictions, tidy = FALSE, atom = FALSE)
+hitrate_4.test <- hitrate(data = multiclass, obs = labels, pred = predictions, tidy = TRUE, atom = FALSE)
+hitrate_5.test <- hitrate(data = multiclass, obs = labels, pred = predictions, tidy = FALSE, atom = TRUE)
+hitrate_6.test <- hitrate(data = multiclass, obs = labels, pred = predictions, tidy = TRUE, atom = TRUE)
+hitrate_7.test <- hitrate(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 2)
+hitrate_8.test <- hitrate(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 2)
+
+# TEST
+test_that('no error hitrate_1', {expect_false(inherits(hitrate_1.test, "try-error")) })
+test_that('no error hitrate_2', {expect_false(inherits(hitrate_2.test, "try-error")) })
+test_that('no error hitrate_3', {expect_false(inherits(hitrate_3.test, "try-error")) })
+test_that('no error hitrate_4', {expect_false(inherits(hitrate_4.test, "try-error")) })
+test_that('no error hitrate_5', {expect_false(inherits(hitrate_5.test, "try-error")) })
+test_that('no error hitrate_6', {expect_false(inherits(hitrate_6.test, "try-error")) })
+test_that('no error hitrate_7', {expect_false(inherits(hitrate_7.test, "try-error")) })
+test_that('no error hitrate_8', {expect_false(inherits(hitrate_8.test, "try-error")) })
+
 # 5. Specificity
 specificity_1.test <- specificity(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 1)
 specificity_2.test <- specificity(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 1)
@@ -111,6 +191,42 @@ test_that('no error specificity_5', {expect_false(inherits(specificity_5.test, "
 test_that('no error specificity_6', {expect_false(inherits(specificity_6.test, "try-error")) })
 test_that('no error specificity_7', {expect_false(inherits(specificity_7.test, "try-error")) })
 
+  # 5.b Selectivity
+selectivity_1.test <- selectivity(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 1)
+selectivity_2.test <- selectivity(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 1)
+selectivity_3.test <- selectivity(data = multiclass, obs = labels, pred = predictions, tidy = FALSE)
+selectivity_4.test <- selectivity(data = multiclass, obs = labels, pred = predictions, tidy = TRUE)
+selectivity_5.test <- selectivity(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 2)
+selectivity_6.test <- selectivity(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 2)
+selectivity_7.test <- selectivity(data = multiclass, obs = labels, pred = predictions, tidy = FALSE, atom = TRUE)
+
+# TEST
+test_that('no error selectivity_1', {expect_false(inherits(selectivity_1.test, "try-error")) })
+test_that('no error selectivity_2', {expect_false(inherits(selectivity_2.test, "try-error")) })
+test_that('no error selectivity_3', {expect_false(inherits(selectivity_3.test, "try-error")) })
+test_that('no error selectivity_4', {expect_false(inherits(selectivity_4.test, "try-error")) })
+test_that('no error selectivity_5', {expect_false(inherits(selectivity_5.test, "try-error")) })
+test_that('no error selectivity_6', {expect_false(inherits(selectivity_6.test, "try-error")) })
+test_that('no error selectivity_7', {expect_false(inherits(selectivity_7.test, "try-error")) })
+
+  # 5.c True Negative Rate
+TNR_1.test <- TNR(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 1)
+TNR_2.test <- TNR(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 1)
+TNR_3.test <- TNR(data = multiclass, obs = labels, pred = predictions, tidy = FALSE)
+TNR_4.test <- TNR(data = multiclass, obs = labels, pred = predictions, tidy = TRUE)
+TNR_5.test <- TNR(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 2)
+TNR_6.test <- TNR(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 2)
+TNR_7.test <- TNR(data = multiclass, obs = labels, pred = predictions, tidy = FALSE, atom = TRUE)
+
+# TEST
+test_that('no error TNR_1', {expect_false(inherits(TNR_1.test, "try-error")) })
+test_that('no error TNR_2', {expect_false(inherits(TNR_2.test, "try-error")) })
+test_that('no error TNR_3', {expect_false(inherits(TNR_3.test, "try-error")) })
+test_that('no error TNR_4', {expect_false(inherits(TNR_4.test, "try-error")) })
+test_that('no error TNR_5', {expect_false(inherits(TNR_5.test, "try-error")) })
+test_that('no error TNR_6', {expect_false(inherits(TNR_6.test, "try-error")) })
+test_that('no error TNR_7', {expect_false(inherits(TNR_7.test, "try-error")) })
+
 # 6. F-score
 fscore_1.test <- fscore(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 1)
 fscore_2.test <- fscore(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 1)
@@ -193,6 +309,22 @@ test_that('no error mcc_4', {expect_false(inherits(mcc_4.test, "try-error")) })
 test_that('no error mcc_5', {expect_false(inherits(mcc_5.test, "try-error")) })
 test_that('no error mcc_6', {expect_false(inherits(mcc_6.test, "try-error")) })
 
+# 10b. phi_coef
+phi_coef_1.test <- phi_coef(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 1)
+phi_coef_2.test <- phi_coef(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 1)
+phi_coef_3.test <- phi_coef(data = multiclass, obs = labels, pred = predictions, tidy = FALSE)
+phi_coef_4.test <- phi_coef(data = multiclass, obs = labels, pred = predictions, tidy = TRUE)
+phi_coef_5.test <- phi_coef(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 2)
+phi_coef_6.test <- phi_coef(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 2)
+
+# TEST
+test_that('no error phi_coef_1', {expect_false(inherits(phi_coef_1.test, "try-error")) })
+test_that('no error phi_coef_2', {expect_false(inherits(phi_coef_2.test, "try-error")) })
+test_that('no error phi_coef_3', {expect_false(inherits(phi_coef_3.test, "try-error")) })
+test_that('no error phi_coef_4', {expect_false(inherits(phi_coef_4.test, "try-error")) })
+test_that('no error phi_coef_5', {expect_false(inherits(phi_coef_5.test, "try-error")) })
+test_that('no error phi_coef_6', {expect_false(inherits(phi_coef_6.test, "try-error")) })
+
 # 11. BMI, Informedness, Youden's J-index
 bmi_1.test <- bmi(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 1)
 bmi_2.test <- bmi(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 1)
@@ -211,6 +343,24 @@ test_that('no error bmi_5', {expect_false(inherits(bmi_5.test, "try-error")) })
 test_that('no error bmi_6', {expect_false(inherits(bmi_6.test, "try-error")) })
 test_that('no error bmi_7', {expect_false(inherits(bmi_7.test, "try-error")) })
 
+# 11b. Jindex
+jindex_1.test <- jindex(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 1)
+jindex_2.test <- jindex(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 1)
+jindex_3.test <- jindex(data = multiclass, obs = labels, pred = predictions, tidy = FALSE)
+jindex_4.test <- jindex(data = multiclass, obs = labels, pred = predictions, tidy = TRUE)
+jindex_5.test <- jindex(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 2)
+jindex_6.test <- jindex(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 2)
+jindex_7.test <- jindex(data = multiclass, obs = labels, pred = predictions, tidy = TRUE, pos_level = 2, atom = TRUE)
+
+# TEST
+test_that('no error jindex_1', {expect_false(inherits(jindex_1.test, "try-error")) })
+test_that('no error jindex_2', {expect_false(inherits(jindex_2.test, "try-error")) })
+test_that('no error jindex_3', {expect_false(inherits(jindex_3.test, "try-error")) })
+test_that('no error jindex_4', {expect_false(inherits(jindex_4.test, "try-error")) })
+test_that('no error jindex_5', {expect_false(inherits(jindex_5.test, "try-error")) })
+test_that('no error jindex_6', {expect_false(inherits(jindex_6.test, "try-error")) })
+test_that('no error jindex_7', {expect_false(inherits(jindex_7.test, "try-error")) })
+
 # 12. AGF
 agf_1.test <- agf(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 1)
 agf_2.test <- agf(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 1)
@@ -450,6 +600,24 @@ test_that('no error csi_5', {expect_false(inherits(csi_5.test, "try-error")) })
 test_that('no error csi_6', {expect_false(inherits(csi_6.test, "try-error")) })
 test_that('no error csi_7', {expect_false(inherits(csi_7.test, "try-error")) })
 
+# 24b. Jaccard Index
+jaccardindex_1.test <- jaccardindex(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 1)
+jaccardindex_2.test <- jaccardindex(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 1)
+jaccardindex_3.test <- jaccardindex(data = multiclass, obs = labels, pred = predictions, tidy = FALSE)
+jaccardindex_4.test <- jaccardindex(data = multiclass, obs = labels, pred = predictions, tidy = TRUE)
+jaccardindex_5.test <- jaccardindex(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 2)
+jaccardindex_6.test <- jaccardindex(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 2)
+jaccardindex_7.test <- jaccardindex(data = multiclass, obs = labels, pred = predictions, tidy = TRUE, pos_level = 2, atom = TRUE)
+
+# TEST
+test_that('no error jaccardindex_1', {expect_false(inherits(jaccardindex_1.test, "try-error")) })
+test_that('no error jaccardindex_2', {expect_false(inherits(jaccardindex_2.test, "try-error")) })
+test_that('no error jaccardindex_3', {expect_false(inherits(jaccardindex_3.test, "try-error")) })
+test_that('no error jaccardindex_4', {expect_false(inherits(jaccardindex_4.test, "try-error")) })
+test_that('no error jaccardindex_5', {expect_false(inherits(jaccardindex_5.test, "try-error")) })
+test_that('no error jaccardindex_6', {expect_false(inherits(jaccardindex_6.test, "try-error")) })
+test_that('no error jaccardindex_7', {expect_false(inherits(jaccardindex_7.test, "try-error")) })
+
 # 25. deltap
 deltap_1.test <- deltap(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 1)
 deltap_2.test <- deltap(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 1)
@@ -468,6 +636,24 @@ test_that('no error deltap_5', {expect_false(inherits(deltap_5.test, "try-error"
 test_that('no error deltap_6', {expect_false(inherits(deltap_6.test, "try-error")) })
 test_that('no error deltap_7', {expect_false(inherits(deltap_7.test, "try-error")) })
 
+# 25b. mk
+mk_1.test <- mk(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 1)
+mk_2.test <- mk(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 1)
+mk_3.test <- mk(data = multiclass, obs = labels, pred = predictions, tidy = FALSE)
+mk_4.test <- mk(data = multiclass, obs = labels, pred = predictions, tidy = TRUE)
+mk_5.test <- mk(data = binary, obs = labels, pred = predictions, tidy = FALSE, pos_level = 2)
+mk_6.test <- mk(data = binary, obs = labels, pred = predictions, tidy = TRUE, pos_level = 2)
+mk_7.test <- mk(data = multiclass, obs = labels, pred = predictions, tidy = FALSE, atom = TRUE)
+
+# TEST
+test_that('no error mk_1', {expect_false(inherits(mk_1.test, "try-error")) })
+test_that('no error mk_2', {expect_false(inherits(mk_2.test, "try-error")) })
+test_that('no error mk_3', {expect_false(inherits(mk_3.test, "try-error")) })
+test_that('no error mk_4', {expect_false(inherits(mk_4.test, "try-error")) })
+test_that('no error mk_5', {expect_false(inherits(mk_5.test, "try-error")) })
+test_that('no error mk_6', {expect_false(inherits(mk_6.test, "try-error")) })
+test_that('no error mk_7', {expect_false(inherits(mk_7.test, "try-error")) })
+
 # 26. AUC_roc
 AUC_roc_1.test <- AUC_roc(data = binary, obs = labels, pred = predictions, tidy = FALSE)
 AUC_roc_2.test <- AUC_roc(data = binary, obs = labels, pred = predictions, tidy = TRUE)
